@@ -57,11 +57,12 @@ namespace ARTICLE
 
         virtual void switch_admin();
 
+        virtual void restore_lasttab();
+
       private:
 
         bool clock_in_smooth_scroll( int timer_number );
 
-        void hide_popup();
         void delete_popup();
         void delete_all_popups();
 
