@@ -7,7 +7,7 @@
 
 #include "dbtree/interface.h"
 #include "dbtree/articlebase.h"
-#include "dbtree/nodetreebase.h"
+#include "dbtree/nodetreedummy.h"
 
 #include "jdlib/miscutil.h"
 
@@ -49,13 +49,16 @@ namespace ARTICLE
 using namespace ARTICLE;
 
 
-// m_show_abone = true ならあぼーんしたレスも表示する
-LayoutTree::LayoutTree( const std::string& url, bool show_abone )
+// show_abone : true ならあぼーんしたレスも表示する
+// show_multispace : true なら連続空白ノードも表示
+LayoutTree::LayoutTree( const std::string& url, const bool show_abone, const bool show_multispace )
     : m_heap( SIZE_OF_HEAP ),
       m_url( url ),
+      m_vec_header( NULL ),
       m_local_nodetree( 0 ),
       m_separator_header( NULL ),
-      m_show_abone( show_abone )
+      m_show_abone( show_abone ),
+      m_show_multispace( show_multispace )
 {
 #ifdef _DEBUG
     std::cout << "LayoutTree::LayoutTree : url = " << url << " show_abone = " << m_show_abone << std::endl;
@@ -82,6 +85,8 @@ LayoutTree::~LayoutTree()
 void LayoutTree::clear()
 {
     m_heap.clear();
+
+    m_vec_header = NULL;
     
     m_last_header = NULL;
     m_max_res_number = 0;
@@ -279,14 +284,14 @@ LAYOUT* LayoutTree::create_layout_sssp( const char* link )
 //
 // joint == true の時はヘッダを作らないで、本文を前のツリーの続きに連結する
 //
-void LayoutTree::append_node( DBTREE::NODE* node_header, bool joint )
+void LayoutTree::append_node( DBTREE::NODE* node_header, const bool joint )
 {
     if( ! node_header ) return;
 
     DBTREE::HEADERINFO* headinfo = node_header->headinfo;
     if( ! headinfo ) return;
 
-    int res_number = node_header->id_header;
+    const int res_number = node_header->id_header;
 
 #ifdef _DEBUG
     std::cout << "LayoutTree::append_node num = " << res_number << " show_abone = " << m_show_abone << std::endl;
@@ -315,6 +320,8 @@ void LayoutTree::append_node( DBTREE::NODE* node_header, bool joint )
         header->res_number = res_number;
         header->node = node_header;
         if( res_number > m_max_res_number ) m_max_res_number = res_number;
+        if( ! m_vec_header ) m_vec_header = ( LAYOUT** ) m_heap.heap_alloc( sizeof( LAYOUT* ) * MAX_RESNUMBER );
+        m_vec_header[ res_number ] = header;
 
         while( dom ){
 
@@ -388,8 +395,9 @@ void LayoutTree::append_block( DBTREE::NODE* block, const int res_number, IMGDAT
                 tmplayout = create_layout_link( tmpnode->text, tmpnode->linkinfo->link,
                                                 &tmpnode->color_text, tmpnode->bold );
                 // 画像リンクのurlを集める
-                if( imgdata && tmpnode->linkinfo->image && imgdata->num < MAX_IMGITEM ){
-                    imgdata->item[ imgdata->num ].link = tmpnode->linkinfo->link;
+                if( imgdata && tmpnode->linkinfo->imglink && imgdata->num < MAX_IMGITEM ){
+
+                    imgdata->item[ imgdata->num ].link = tmpnode->linkinfo->imglink;
                     imgdata->item[ imgdata->num++ ].node = tmpnode;
                 }
 
@@ -425,6 +433,10 @@ void LayoutTree::append_block( DBTREE::NODE* block, const int res_number, IMGDAT
                 tmplayout = create_layout_hspace( tmpnode->type );
                 break;
 
+            case DBTREE::NODE_MULTISP: // 連続半角スペース
+                if( m_show_multispace ) tmplayout = create_layout_text( tmpnode->text, &tmpnode->color_text, tmpnode->bold );
+                break;
+
             case DBTREE::NODE_HTAB: // 水平タブ
                 tmplayout = create_layout_hspace( tmpnode->type );
                 break;
@@ -446,8 +458,9 @@ void LayoutTree::append_block( DBTREE::NODE* block, const int res_number, IMGDAT
 //
 void LayoutTree::append_abone_node( DBTREE::NODE* node_header )
 {
-    int res_number = node_header->id_header;
+    const int res_number = node_header->id_header;
     if( res_number > m_max_res_number ) m_max_res_number = res_number;
+    if( ! m_vec_header ) m_vec_header = ( LAYOUT** ) m_heap.heap_alloc( sizeof( LAYOUT* ) * MAX_RESNUMBER );
 
 #ifdef _DEBUG
     std::cout << "LayoutTree::append_abone_node num = " << res_number << std::endl;
@@ -457,6 +470,8 @@ void LayoutTree::append_abone_node( DBTREE::NODE* node_header )
     if( ! m_show_abone && m_article->get_abone_transparent() ) return;
 
     LAYOUT* head = create_layout_header();
+    m_vec_header[ res_number ] = head;
+
     head->res_number = res_number;
 
     int classid = CORE::get_css_manager()->get_classid( "title" );
@@ -485,7 +500,7 @@ void LayoutTree::append_html( const std::string& html )
     std::cout << "LayoutTree::append_html url = " << m_url << " html = " << html << std::endl;
 #endif    
 
-    if( ! m_local_nodetree ) m_local_nodetree = new DBTREE::NodeTreeDummy( m_url, std::string() );
+    if( ! m_local_nodetree ) m_local_nodetree = new DBTREE::NodeTreeDummy( m_url );
     DBTREE::NODE* node_header = m_local_nodetree->append_html( html );
 
     LAYOUT* header = create_layout_header();
@@ -531,27 +546,14 @@ void LayoutTree::append_dat( const std::string& dat, int num )
 //
 // レス番号 number のヘッダを返す
 //
-const LAYOUT* LayoutTree::get_header_of_res_const( int number ){ return get_header_of_res( number ); }
+const LAYOUT* LayoutTree::get_header_of_res_const( const int number ){ return get_header_of_res( number ); }
 
-LAYOUT* LayoutTree::get_header_of_res( int number )
+LAYOUT* LayoutTree::get_header_of_res( const int number )
 {
-#ifdef _DEBUG
-    std::cout << "LayoutTree::get_header_of_res num = " << number << std::endl;
-#endif  
+    if( ! m_vec_header ) return NULL;
+    if( number > m_max_res_number || number <= 0 ) return NULL;
 
-    LAYOUT* tmpheader = top_header();
-    while( tmpheader ){
-
-        if( tmpheader->res_number == number ) return tmpheader;
-
-        tmpheader = tmpheader->next_header;
-    }
-
-#ifdef _DEBUG
-    std::cout << "not found.\n";
-#endif  
-
-    return NULL;
+    return m_vec_header[ number ];
 }
 
 
@@ -597,7 +599,7 @@ void LayoutTree::move_separator()
 
     if( ! num ) return;
 
-    // あぼーんしているレスは飛ばす
+    // 透明あぼーんしているレスは飛ばす
     int num_tmp = num;
     while( ! ( header_after = get_header_of_res( num_tmp ) ) && num_tmp++ < m_max_res_number );
     if( ! header_after ) return;
