@@ -2,6 +2,7 @@
 
 //#define _DEBUG
 #include "jddebug.h"
+#include "gtkmmversion.h"
 
 #include "boardadmin.h"
 #include "boardview.h"
@@ -48,6 +49,7 @@ using namespace BOARD;
 
 
 enum{
+    CANCEL_OPENROW = 500,  // msec  連続クリック防止用カウンタ
     DEFAULT_COLMUN_WIDTH = 50
 };
 
@@ -102,11 +104,13 @@ BoardViewBase::BoardViewBase( const std::string& url, const bool show_col_board
       m_col_board( NULL ),
       m_col_subject( NULL ),
       m_col_res( NULL ),
-      m_col_str_load( NULL ),     
+      m_col_str_load( NULL ),
       m_col_str_new( NULL ),
       m_col_since( NULL ),
       m_col_write( NULL ),
+      m_col_access( NULL ),
       m_col_speed( NULL ),
+      m_col_diff( NULL ),
       m_clicked( false ),
       m_col( COL_NUM_COL ),
       m_previous_col( COL_NUM_COL ),
@@ -115,7 +119,9 @@ BoardViewBase::BoardViewBase( const std::string& url, const bool show_col_board
       m_loading( false ),
       m_enable_menuslot( true ),
       m_load_subject_txt( true ),
-      m_show_col_board( show_col_board )
+      m_show_col_board( show_col_board ),
+      m_col_diff_is_shown( false ),
+      m_cancel_openrow_counter( 0 )
 {
     // 次スレ検索ビューのようにURLの途中に http が入っている場合は取り除く
     const size_t pos = url.rfind( "http://" );
@@ -126,17 +132,17 @@ BoardViewBase::BoardViewBase( const std::string& url, const bool show_col_board
     m_scrwin.set_policy( Gtk::POLICY_AUTOMATIC, Gtk::POLICY_ALWAYS );
 
     pack_start( m_scrwin );
-    show_all_children();    
+    show_all_children();
 
     // ツリービュー設定
     m_liststore = Gtk::ListStore::create( m_columns );
 
-#if GTKMMVER <= 260
+#if !GTKMM_CHECK_VERSION(2,7,0)
     // gtkmm26以下にはunset_model()が無いのでここでset_model()しておく
     m_treeview.set_model( m_liststore );
 #endif
 
-#if GTKMMVER >= 260
+#if GTKMM_CHECK_VERSION(2,6,0)
 
     // セルを固定の高さにする
     // append_column する前に columnに対して set_sizing( Gtk::TREE_VIEW_COLUMN_FIXED ) すること
@@ -152,7 +158,7 @@ BoardViewBase::BoardViewBase( const std::string& url, const bool show_col_board
     update_columns();
 
     // ソート関数セット
-    m_liststore->set_sort_func( COL_MARK, sigc::mem_fun( *this, &BoardViewBase::slot_compare_row ) );    
+    m_liststore->set_sort_func( COL_MARK, sigc::mem_fun( *this, &BoardViewBase::slot_compare_row ) );
     m_liststore->set_sort_func( COL_ID, sigc::mem_fun( *this, &BoardViewBase::slot_compare_row ) );
     m_liststore->set_sort_func( COL_BOARD, sigc::mem_fun( *this, &BoardViewBase::slot_compare_row ) );
     m_liststore->set_sort_func( COL_SUBJECT, sigc::mem_fun( *this, &BoardViewBase::slot_compare_row ) );
@@ -161,8 +167,10 @@ BoardViewBase::BoardViewBase( const std::string& url, const bool show_col_board
     m_liststore->set_sort_func( COL_STR_NEW, sigc::mem_fun( *this, &BoardViewBase::slot_compare_row ) );
     m_liststore->set_sort_func( COL_SINCE, sigc::mem_fun( *this, &BoardViewBase::slot_compare_row ) );
     m_liststore->set_sort_func( COL_WRITE, sigc::mem_fun( *this, &BoardViewBase::slot_compare_row ) );
+    m_liststore->set_sort_func( COL_ACCESS, sigc::mem_fun( *this, &BoardViewBase::slot_compare_row ) );
     m_liststore->set_sort_func( COL_SPEED, sigc::mem_fun( *this, &BoardViewBase::slot_compare_row ) );
-    
+    m_liststore->set_sort_func( COL_DIFF, sigc::mem_fun( *this, &BoardViewBase::slot_compare_row ) );
+
     m_treeview.sig_button_press().connect( sigc::mem_fun(*this, &BoardViewBase::slot_button_press ) );
     m_treeview.sig_button_release().connect( sigc::mem_fun(*this, &BoardViewBase::slot_button_release ) );
     m_treeview.sig_motion_notify().connect( sigc::mem_fun(*this, &BoardViewBase::slot_motion_notify ) );
@@ -185,7 +193,7 @@ BoardViewBase::BoardViewBase( const std::string& url, const bool show_col_board
 
 BoardViewBase::~BoardViewBase()
 {
-#ifdef _DEBUG    
+#ifdef _DEBUG
     std::cout << "BoardViewBase::~BoardViewBase : " << get_url() << std::endl;
 #endif
 }
@@ -218,7 +226,7 @@ const int BoardViewBase::get_icon( const std::string& iconname )
     if( iconname == "default" ) id = ICON::BOARD;
     if( iconname == "loading" ) id = ICON::LOADING;
     if( iconname == "loading_stop" ) id = ICON::LOADING_STOP;
-    if( iconname == "update" ) id = ICON::BOARD_UPDATE;  // 更新チェックしで更新があった場合
+    if( iconname == "update" ) id = ICON::BOARD_UPDATE;  // 更新チェックして更新があった場合
     if( iconname == "updated" ) id = ICON::BOARD_UPDATED;
 
 #ifdef _DEBUG
@@ -243,7 +251,7 @@ const std::string BoardViewBase::url_for_copy()
 //
 void BoardViewBase::setup_action()
 {
-#ifdef _DEBUG    
+#ifdef _DEBUG
     std::cout << "BoardViewBase::setup_action\n";
 #endif
 
@@ -256,6 +264,8 @@ void BoardViewBase::setup_action()
     action_group()->add( Gtk::Action::create( "UnsetBookMark", "しおりを解除(_U)" ),    // 未使用
                          sigc::bind< int >( sigc::mem_fun( *this, &BoardViewBase::slot_bookmark ), BOOKMARK_UNSET ) );
     action_group()->add( Gtk::Action::create( "OpenTab", "OpenArticleTab" ), sigc::mem_fun( *this, &BoardViewBase::slot_open_tab ) );
+    action_group()->add( Gtk::Action::create( "RegetArticle", ITEM_NAME_REGETARTICLE + std::string( "(_R)" ) ),
+                         sigc::mem_fun( *this, &BoardViewBase::slot_reget_article ) );
     action_group()->add( Gtk::Action::create( "Favorite_Article", ITEM_NAME_FAVORITE_ARTICLE + std::string( "(_F)..." ) ),
                          sigc::mem_fun( *this, &BoardViewBase::slot_favorite_thread ) );
     action_group()->add( Gtk::Action::create( "Favorite_Board", "板をお気に入りに追加(_A)" ), sigc::mem_fun( *this, &BoardViewBase::slot_favorite_board ) );
@@ -263,7 +273,10 @@ void BoardViewBase::setup_action()
     action_group()->add( Gtk::Action::create( "GotoBottom", "一番下に移動(_M)" ), sigc::mem_fun( *this, &BoardViewBase::goto_bottom ) );
     action_group()->add( Gtk::Action::create( "Delete_Menu", "Delete" ) );
     action_group()->add( Gtk::Action::create( "Delete", "選択した行のログを削除する(_D)" ), sigc::mem_fun( *this, &BoardViewBase::slot_delete_logs ) );
-    action_group()->add( Gtk::Action::create( "OpenRows", "選択した行を開く(_O)" ), sigc::mem_fun( *this, &BoardViewBase::open_selected_rows ) );
+    action_group()->add( Gtk::Action::create( "OpenRows", "選択したスレを開く(_O)" ),
+                         sigc::bind< bool >( sigc::mem_fun( *this, &BoardViewBase::open_selected_rows ), false ) );
+    action_group()->add( Gtk::Action::create( "RegetRows", "スレ情報を消さずにスレを再取得(_R)" ),
+                         sigc::bind< bool >( sigc::mem_fun( *this, &BoardViewBase::open_selected_rows ), true ) );
     action_group()->add( Gtk::Action::create( "CopyURL", ITEM_NAME_COPY_URL + std::string( "(_U)" ) ), sigc::mem_fun( *this, &BoardViewBase::slot_copy_url ) );
     action_group()->add( Gtk::Action::create( "CopyTitleURL", ITEM_NAME_COPY_TITLE_URL + std::string( "(_L)" ) ),
                          sigc::mem_fun( *this, &BoardViewBase::slot_copy_title_url ) );
@@ -284,7 +297,7 @@ void BoardViewBase::setup_action()
     action_group()->add( Gtk::Action::create( "Etc_Menu", ITEM_NAME_ETC + std::string( "(_O)" ) ) );
 
     ui_manager().clear();
-    ui_manager() = Gtk::UIManager::create();    
+    ui_manager() = Gtk::UIManager::create();
     ui_manager()->insert_action_group( action_group() );
 
     // 通常 + 複数
@@ -292,6 +305,8 @@ void BoardViewBase::setup_action()
     "<popup name='popup_menu_mul'>"
     "<menuitem action='OpenRows'/>"
     "<separator/>"
+    "<menuitem action='RegetRows'/>"
+    "<separator/>"
     "<menuitem action='SetBookMark'/>"
     "<menuitem action='UnsetBookMark'/>"
     "<separator/>"
@@ -320,7 +335,7 @@ void BoardViewBase::setup_action()
     "</popup>";
 
     // 削除ボタン押した時のメニュー
-    const std::string menu_delete = 
+    const std::string menu_delete =
     "<popup name='popup_menu_delete'>"
     "<menuitem action='Delete'/>"
     "</popup>";
@@ -353,6 +368,7 @@ const std::string BoardViewBase::create_context_menu()
 
     list_menu.push_back( ITEM_BOOKMARK );
     list_menu.push_back( ITEM_OPENARTICLETAB );
+    list_menu.push_back( ITEM_REGETARTICLE );
     list_menu.push_back( ITEM_OPEN_BROWSER );
     list_menu.push_back( ITEM_COPY_URL );
     list_menu.push_back( ITEM_COPY_TITLE_URL_THREAD );
@@ -414,6 +430,10 @@ const char* BoardViewBase::get_menu_item( const int item )
         case ITEM_OPENARTICLETAB:
             return "<menuitem action='OpenTab'/>";
 
+            // スレ情報を消さずに再取得"
+        case ITEM_REGETARTICLE:
+            return "<menuitem action='RegetArticle'/>";
+
             // リンクをブラウザで開く
         case ITEM_OPEN_BROWSER:
             return "<menuitem action='OpenBrowser'/>";
@@ -522,6 +542,8 @@ void BoardViewBase::update_columns()
     DELETE_COLUMN( m_col_since );
     DELETE_COLUMN( m_col_write );
     DELETE_COLUMN( m_col_speed );
+    DELETE_COLUMN( m_col_diff );
+    DELETE_COLUMN( m_col_access );
 
     int num = 0;
 
@@ -538,6 +560,7 @@ void BoardViewBase::update_columns()
         if( append_board ) APPEND_COLUMN( m_col_board, ITEM_NAME_BOARD, m_columns.m_col_board );
     }
 
+    m_col_diff_is_shown = false;
     num = 0;
     for(;;){
         const int item = SESSION::get_item_board_col( num );
@@ -552,14 +575,16 @@ void BoardViewBase::update_columns()
             case ITEM_NEW: APPEND_COLUMN( m_col_str_new, ITEM_NAME_NEW, m_columns.m_col_str_new ); break;
             case ITEM_SINCE: APPEND_COLUMN( m_col_since, ITEM_NAME_SINCE, m_columns.m_col_since ); break;
             case ITEM_LASTWRITE: APPEND_COLUMN( m_col_write, ITEM_NAME_LASTWRITE, m_columns.m_col_write ); break;
+            case ITEM_ACCESS: APPEND_COLUMN( m_col_access, ITEM_NAME_ACCESS, m_columns.m_col_access); break;
             case ITEM_SPEED: APPEND_COLUMN( m_col_speed, ITEM_NAME_SPEED, m_columns.m_col_speed ); break;
+            case ITEM_DIFF: APPEND_COLUMN( m_col_diff, ITEM_NAME_DIFF, m_columns.m_col_diff); m_col_diff_is_shown = true; break;
         }
         ++num;
     }
 
     // サイズを調整しつつソートの設定
     for( guint i = 0; i < COL_VISIBLE_END; i++ ){
-        
+
         const int id = get_title_id( i );
         if( id < 0 ) continue;
 
@@ -607,8 +632,16 @@ void BoardViewBase::update_columns()
             width = SESSION::col_write();
             break;
 
+        case COL_ACCESS:
+            width = SESSION::col_access();
+            break;
+
         case COL_SPEED:
-            width = SESSION::col_speed(); 
+            width = SESSION::col_speed();
+            break;
+
+        case COL_DIFF:
+            width = SESSION::col_diff();
             break;
         }
 
@@ -616,7 +649,7 @@ void BoardViewBase::update_columns()
 
         column->set_fixed_width( width );
         column->set_resizable( true );
-        column->set_clickable( true );        
+        column->set_clickable( true );
 
         // ヘッダをクリックしたときに呼ぶslot
         column->signal_clicked().connect( sigc::bind< int >( sigc::mem_fun( *this, &BoardViewBase::slot_col_clicked ), id ) );
@@ -632,6 +665,7 @@ void BoardViewBase::update_columns()
             case COL_STR_LOAD:
             case COL_STR_NEW:
             case COL_SPEED:
+            case COL_DIFF:
                 column->set_alignment( 1.0 );
                 break;
 
@@ -661,6 +695,7 @@ void BoardViewBase::update_columns()
                 case COL_STR_LOAD:
                 case COL_STR_NEW:
                 case COL_SPEED:
+                case COL_DIFF:
                     rentext->property_xalign() = 1.0;
                     break;
 
@@ -694,7 +729,9 @@ const int BoardViewBase::get_title_id( const int col )
     else if( title == ITEM_NAME_NEW ) id = COL_STR_NEW;
     else if( title == ITEM_NAME_SINCE ) id = COL_SINCE;
     else if( title == ITEM_NAME_LASTWRITE ) id = COL_WRITE;
+    else if( title == ITEM_NAME_ACCESS ) id = COL_ACCESS;
     else if( title == ITEM_NAME_SPEED ) id = COL_SPEED;
+    else if( title == ITEM_NAME_DIFF ) id = COL_DIFF;
 
     return id;
 }
@@ -724,10 +761,10 @@ void BoardViewBase::save_column_width()
 {
 #ifdef _DEBUG
     std::cout << "save_column_width " << get_url() << std::endl;
-#endif    
+#endif
 
     for( guint i = 0; i < COL_VISIBLE_END; i++ ){
-        
+
         const int id = get_title_id( i );
         if( id < 0 ) continue;
 
@@ -775,13 +812,21 @@ void BoardViewBase::save_column_width()
             SESSION::set_col_write( width );
             break;
 
+        case COL_ACCESS:
+            SESSION::set_col_access( width );
+            break;
+
         case COL_SPEED:
             SESSION::set_col_speed( width );
             break;
+
+        case COL_DIFF:
+            SESSION::set_col_diff( width );
+            break;
         }
     }
-} 
-   
+}
+
 
 
 //
@@ -1006,8 +1051,8 @@ const int BoardViewBase::compare_col( const int col, const int sortmode, Gtk::Tr
         case COL_SUBJECT:
         {
             // 文字列の大小を数字に変換
-            const Glib::ustring name_a = row_a[ m_columns.m_col_subject ]; 
-            const Glib::ustring name_b = row_b[ m_columns.m_col_subject ]; 
+            const Glib::ustring name_a = row_a[ m_columns.m_col_subject ];
+            const Glib::ustring name_b = row_b[ m_columns.m_col_subject ];
             if( name_a < name_b ) { num_a = UP; num_b = DOWN; }
             else if( name_a > name_b ) { num_a = DOWN; num_b = UP; }
             break;
@@ -1042,16 +1087,26 @@ const int BoardViewBase::compare_col( const int col, const int sortmode, Gtk::Tr
             num_b = row_b[ m_columns.m_col_write_t ];
             break;
 
+        case COL_ACCESS:
+            num_a = row_a[ m_columns.m_col_access_t ];
+            num_b = row_b[ m_columns.m_col_access_t ];
+            break;
+
         case COL_SPEED:
             num_a = row_a[ m_columns.m_col_speed ];
             num_b = row_b[ m_columns.m_col_speed ];
             break;
 
+        case COL_DIFF:
+            num_a = row_a[ m_columns.m_col_diff ];
+            num_b = row_b[ m_columns.m_col_diff ];
+            break;
+
         case COL_BOARD:
         {
             // 文字列の大小を数字に変換
-            Glib::ustring name_a = row_a[ m_columns.m_col_board ]; 
-            Glib::ustring name_b = row_b[ m_columns.m_col_board ]; 
+            Glib::ustring name_a = row_a[ m_columns.m_col_board ];
+            Glib::ustring name_b = row_b[ m_columns.m_col_board ];
             if( name_a < name_b ) { num_a = UP; num_b = DOWN; }
             else if( name_a > name_b ) { num_a = DOWN; num_b = UP; }
             break;
@@ -1089,12 +1144,12 @@ const int BoardViewBase::slot_compare_row( const Gtk::TreeModel::iterator& a, co
     Gtk::TreeModel::Row row_b = *( b );
 
     // 抽出状態を最優先
-    int ret = compare_drawbg( row_a, row_b ); 
+    int ret = compare_drawbg( row_a, row_b );
 
     if( ! ret ) ret = compare_col( m_col, m_sortmode, row_a, row_b );
 
     // マルチキーソート
-    if( ! ret ) ret = compare_col( m_previous_col, m_previous_sortmode, row_a, row_b );  
+    if( ! ret ) ret = compare_col( m_previous_col, m_previous_sortmode, row_a, row_b );
 
     if( ! ret ) ret = compare_col( COL_MARK, SORTMODE_ASCEND, row_a, row_b );
     if( ! ret ) ret = compare_col( COL_ID, SORTMODE_ASCEND, row_a, row_b );
@@ -1111,6 +1166,7 @@ const bool BoardViewBase::set_command( const std::string& command, const std::st
     if( command == "update_columns" ) update_columns();
 
     else if( command == "draw_bg_articles" ) draw_bg_articles();
+    else if( command == "clear_highlight" ) clear_highlight();
 
     return true;
 }
@@ -1124,6 +1180,8 @@ void BoardViewBase::clock_in()
     View::clock_in();
 
     m_treeview.clock_in();
+
+    if( m_cancel_openrow_counter ) --m_cancel_openrow_counter;
 }
 
 
@@ -1152,7 +1210,7 @@ void BoardViewBase::show_view()
 
     m_pre_query = std::string();
     m_last_access_time = DBTREE::board_last_access_time( get_url_board() );
-    
+
     // オートリロードのカウンタを0にする
     reset_autoreload_counter();
 
@@ -1162,6 +1220,8 @@ void BoardViewBase::show_view()
         return;
     }
 
+    if( m_col_diff_is_shown ) DBTREE::board_read_subject_from_cache( get_url_board() );
+
     // download 開始
     // 終わったら update_view() が呼ばれる
 
@@ -1220,10 +1280,10 @@ void BoardViewBase::update_view_impl( const std::vector< DBTREE::ArticleBase* >&
               << " code = " << code
               << " size = " << list_article.size()
               << std::endl;
-#endif    
+#endif
 
     // 画面消去
-#if GTKMMVER >= 280
+#if GTKMM_CHECK_VERSION(2,8,0)
     m_treeview.unset_model();
 #endif
 
@@ -1240,7 +1300,7 @@ void BoardViewBase::update_view_impl( const std::vector< DBTREE::ArticleBase* >&
             prepend_row( art, i + 1 );
         }
 
-#if GTKMMVER >= 280
+#if GTKMM_CHECK_VERSION(2,8,0)
         m_treeview.set_model( m_liststore );
 #endif
 
@@ -1327,6 +1387,8 @@ void BoardViewBase::slot_delete_logs()
 //
 const bool BoardViewBase::operate_view( const int control )
 {
+    if( CONTROL::operate_common( control, get_url(), BOARD::get_admin() ) ) return true;
+
     bool open_tab = false;
 
     Gtk::TreePath path = m_treeview.get_current_path();;
@@ -1352,7 +1414,7 @@ const bool BoardViewBase::operate_view( const int control )
         case CONTROL::Home:
             goto_top();
             break;
-            
+
         case CONTROL::End:
             goto_bottom();
             break;
@@ -1361,7 +1423,7 @@ const bool BoardViewBase::operate_view( const int control )
         case CONTROL::SelectAll:
             slot_select_all();
             break;
-    
+
             // お気に入りに追加
         case CONTROL::AppendFavorite:
         {
@@ -1380,7 +1442,7 @@ const bool BoardViewBase::operate_view( const int control )
         case CONTROL::OpenArticleTab:
             open_tab = true;
         case CONTROL::OpenArticle:
-            if( ! path.empty() ) open_row( path, open_tab );
+            if( ! path.empty() ) open_row( path, open_tab, false );
             break;
 
             // Listに戻る
@@ -1405,59 +1467,6 @@ const bool BoardViewBase::operate_view( const int control )
             CORE::core_set_command( "toggle_article" );
             break;
 
-        case CONTROL::TabLeft:
-            BOARD::get_admin()->set_command( "tab_left" );
-            break;
-
-        case CONTROL::TabLeftUpdated:
-            BOARD::get_admin()->set_command( "tab_left_updated" );
-            break;
-
-        case CONTROL::TabRight:
-            BOARD::get_admin()->set_command( "tab_right" );
-            break;
-
-        case CONTROL::TabRightUpdated:
-            BOARD::get_admin()->set_command( "tab_right_updated" );
-            break;
-
-        // タブ位置(1-9)で移動
-        case CONTROL::TabNum1:
-            BOARD::get_admin()->set_command( "tab_num", "", "1" );
-            break;
-
-        case CONTROL::TabNum2:
-            BOARD::get_admin()->set_command( "tab_num", "", "2" );
-            break;
-
-        case CONTROL::TabNum3:
-            BOARD::get_admin()->set_command( "tab_num", "", "3" );
-            break;
-
-        case CONTROL::TabNum4:
-            BOARD::get_admin()->set_command( "tab_num", "", "4" );
-            break;
-
-        case CONTROL::TabNum5:
-            BOARD::get_admin()->set_command( "tab_num", "", "5" );
-            break;
-
-        case CONTROL::TabNum6:
-            BOARD::get_admin()->set_command( "tab_num", "", "6" );
-            break;
-
-        case CONTROL::TabNum7:
-            BOARD::get_admin()->set_command( "tab_num", "", "7" );
-            break;
-
-        case CONTROL::TabNum8:
-            BOARD::get_admin()->set_command( "tab_num", "", "8" );
-            break;
-
-        case CONTROL::TabNum9:
-            BOARD::get_admin()->set_command( "tab_num", "", "9" );
-            break;
-
             // 戻る、進む
         case CONTROL::PrevView:
             back_viewhistory( 1 );
@@ -1521,26 +1530,11 @@ const bool BoardViewBase::operate_view( const int control )
         case CONTROL::SearchNext:
             down_search();
             break;
-    
+
         case CONTROL::SearchPrev:
             up_search();
             break;
 
-            // サイドバー表示/非表示
-        case CONTROL::ShowSideBar:
-            CORE::core_set_command( "toggle_sidebar" );
-            break;
-
-            // メニューバー表示/非表示
-        case CONTROL::ShowMenuBar:
-            CORE::core_set_command( "toggle_menubar" );
-            break;
-
-            // URLを開くダイアログを表示
-        case CONTROL::OpenURL:
-            CORE::core_set_command( "show_openurl_diag" );
-            break;
-
         default:
             return false;
     }
@@ -1578,13 +1572,13 @@ void BoardViewBase::goto_num( const int num, const int )
     if( ! num ) return;
 
     focus_view();
-   
+
     Gtk::TreeModel::Children child = m_liststore->children();
     Gtk::TreeModel::Children::iterator it = child.begin();
     for( ; it != child.end() ; ++it ){
 
         Gtk::TreeModel::Row row = *( it );
-        
+
         if( row[ m_columns.m_col_id ] == num ){
 
             Gtk::TreePath path = GET_PATH( row );
@@ -1626,7 +1620,7 @@ void BoardViewBase::scroll_right()
 void BoardViewBase::row_up()
 {
     m_treeview.row_up();
-}    
+}
 
 
 //
@@ -1635,8 +1629,8 @@ void BoardViewBase::row_up()
 void BoardViewBase::row_down()
 {
     m_treeview.row_down();
-} 
-   
+}
+
 
 //
 // page up
@@ -1644,7 +1638,7 @@ void BoardViewBase::row_down()
 void BoardViewBase::page_up()
 {
     m_treeview.page_up();
-}    
+}
 
 
 //
@@ -1653,8 +1647,8 @@ void BoardViewBase::page_up()
 void BoardViewBase::page_down()
 {
     m_treeview.page_down();
-} 
-   
+}
+
 
 //
 // ポップアップメニューを表示する前にメニューのアクティブ状態を切り替える
@@ -1724,7 +1718,7 @@ Gtk::Menu* BoardViewBase::get_popupmenu( const std::string& url )
     }
 
     // 複数選択メニュー
-    else{ 
+    else{
         m_path_selected = Gtk::TreeModel::Path();
         popupmenu = dynamic_cast< Gtk::Menu* >( ui_manager()->get_widget( "/popup_menu_mul" ) );
     }
@@ -1758,7 +1752,7 @@ void BoardViewBase::update_item( const std::string& url, const std::string& id )
 #endif
 
     unsorted_column();
-   
+
     const Gtk::TreeModel::Row row = get_row_from_url( url_dat );
     if( row ) update_row_common( row );
 }
@@ -1774,8 +1768,8 @@ void BoardViewBase::update_item_all()
     std::cout << "BoardViewBase::update_item_all " << get_url() << std::endl;
 #endif
 
-    unsorted_column(); 
-   
+    unsorted_column();
+
     Gtk::TreeModel::Children child = m_liststore->children();
     Gtk::TreeModel::Children::iterator it;
     for( it = child.begin() ; it != child.end() ; ++it ){
@@ -1786,10 +1780,6 @@ void BoardViewBase::update_item_all()
         DBTREE::ArticleBase* art = row[ m_columns.m_col_article ];
         if( ! art ) continue;
 
-        // since と write の表示形式を変更
-        art->reset_since_date();
-        art->reset_write_date();
-
         update_row_common( row );
     }
 }
@@ -1807,8 +1797,10 @@ const Gtk::TreeModel::Row BoardViewBase::prepend_row( DBTREE::ArticleBase* art,
     if( ( art->get_status() & STATUS_NORMAL ) && ! art->is_924() )
         row[ m_columns.m_col_speed ] = art->get_speed();
 
+    row[ m_columns.m_col_diff ] = art->get_number_diff();
+
     if( m_col_board ) row[ m_columns.m_col_board ] = DBTREE::board_name( art->get_url() );
-        
+
     row[ m_columns.m_col_article ] = art;
 
     row[ m_columns.m_col_drawbg ] = false;
@@ -1862,7 +1854,7 @@ void BoardViewBase::update_row_common( const Gtk::TreeModel::Row& row )
     int mark_val;
     int icon;
 
-    // ブックマーク 
+    // ブックマーク
     if( art->is_bookmarked_thread() ){
 
         //  新着あり
@@ -1886,7 +1878,7 @@ void BoardViewBase::update_row_common( const Gtk::TreeModel::Row& row )
     // dat落ち
     else if( art->get_status() & STATUS_OLD ){
         mark_val = COL_MARKVAL_OLD;
-        icon = ICON::DOWN;
+        icon = ICON::OLD;
     }
 
     // キャッシュはあるが規定のレス数を越えていて全てのレスが既読
@@ -1967,6 +1959,19 @@ void BoardViewBase::update_row_common( const Gtk::TreeModel::Row& row )
         if( mark_val < COL_MARKVAL_NORMAL ) row[ m_columns.m_col_write_t ] = 0;
         else row[ m_columns.m_col_write_t ] = -1;
     }
+
+    // ユーザが最後にロードした時間
+    if( art->get_access_time() ){
+        row[ m_columns.m_col_access ] = art->get_access_date();
+        row[ m_columns.m_col_access_t ] = art->get_access_time();
+    }
+    else{
+        row[ m_columns.m_col_access ] = std::string();
+
+        // DAT落ちしたスレや1000に到達したスレなどは書き込んでいてもソート時の優先度を下げる
+        if( mark_val < COL_MARKVAL_NORMAL ) row[ m_columns.m_col_access_t ] = 0;
+        else row[ m_columns.m_col_access_t ] = -1;
+    }
 }
 
 
@@ -1975,10 +1980,17 @@ void BoardViewBase::update_row_common( const Gtk::TreeModel::Row& row )
 //
 const bool BoardViewBase::slot_button_press( GdkEventButton* event )
 {
-#ifdef _DEBUG        
+#ifdef _DEBUG
     std::cout << "BoardViewBase::slot_button_press\n";
 #endif
 
+    if( m_cancel_openrow_counter ){
+#ifdef _DEBUG
+        std::cout << "canceled\n";
+#endif
+        return true;
+    }
+
     m_clicked = true;
 
     // マウスジェスチャ
@@ -1990,7 +2002,7 @@ const bool BoardViewBase::slot_button_press( GdkEventButton* event )
     // ダブルクリック
     // button_release_eventでは event->type に必ず GDK_BUTTON_RELEASE が入る
     m_dblclicked = false;
-    if( event->type == GDK_2BUTTON_PRESS ) m_dblclicked = true; 
+    if( event->type == GDK_2BUTTON_PRESS ) m_dblclicked = true;
 
     BOARD::get_admin()->set_command( "switch_admin" );
 
@@ -2011,7 +2023,7 @@ const bool BoardViewBase::slot_button_release( GdkEventButton* event )
     const int mg = get_control().MG_end( event );
 
     // ホイールマウスジェスチャ
-    // 実行された場合は何もしない 
+    // 実行された場合は何もしない
     if( get_control().MG_wheel_end( event ) ) return true;
 
     if( mg != CONTROL::None && enable_mg() ){
@@ -2032,17 +2044,17 @@ const bool BoardViewBase::slot_button_release( GdkEventButton* event )
     Gtk::TreeViewColumn* column;
     int cell_x;
     int cell_y;
-   
+
     // 座標からpath取得
     if( m_treeview.get_path_at_pos( x, y, path, column, cell_x, cell_y ) ){
 
         m_path_selected = path;
 
-#ifdef _DEBUG        
+#ifdef _DEBUG
         std::cout << "BoardViewBase::slot_button_release : path = " << path.to_string()
                   << " title = " << column->get_title()
                   << " x = " << x << " y = " << y
-                  << " cellheight = " << m_treeview.get_row_height() 
+                  << " cellheight = " << m_treeview.get_row_height()
                   << " cell_x = " << cell_x << " cell_y = " << cell_y << std::endl;
 #endif
 
@@ -2057,9 +2069,9 @@ const bool BoardViewBase::slot_button_release( GdkEventButton* event )
         if( openarticle || openarticletab ){
 
             // 複数行選択中
-            if( m_treeview.get_selected_iterators().size() >= 2 ) open_selected_rows();
+            if( m_treeview.get_selected_iterators().size() >= 2 ) open_selected_rows( false );
 
-            else open_row( path, openarticletab );
+            else open_row( path, openarticletab, false );
         }
 
         // ポップアップメニューボタン
@@ -2103,6 +2115,7 @@ const bool BoardViewBase::slot_motion_notify( GdkEventMotion* event )
         else if( column->get_title() == ITEM_NAME_NAME ) m_treeview.set_str_tooltip( get_name_of_cell( path, m_columns.m_col_subject ) );
         else if( column->get_title() == ITEM_NAME_SINCE ) m_treeview.set_str_tooltip( get_name_of_cell( path, m_columns.m_col_since ) );
         else if( column->get_title() == ITEM_NAME_LASTWRITE ) m_treeview.set_str_tooltip( get_name_of_cell( path, m_columns.m_col_write ) );
+        else if( column->get_title() == ITEM_NAME_ACCESS ) m_treeview.set_str_tooltip( get_name_of_cell( path, m_columns.m_col_access ) );
         else m_treeview.set_str_tooltip( std::string() );
     }
 
@@ -2151,7 +2164,7 @@ const bool BoardViewBase::slot_key_release( GdkEventKey* event )
         if( key == CONTROL::OpenArticle ) operate_view( key );
         if( key == CONTROL::OpenArticleTab ) operate_view( key );
     }
-   
+
     return true;
 }
 
@@ -2213,7 +2226,7 @@ void BoardViewBase::slot_dropped_url_list( const std::list< std::string >& url_l
         info.url = MISC::remove_str( ( *it ), "file://" );
         list_info.push_back( info );
 
-#ifdef _DEBUG    
+#ifdef _DEBUG
         std::cout << "append " << info.url << std::endl;
 #endif
     }
@@ -2250,7 +2263,16 @@ void BoardViewBase::slot_bookmark( const int bookmark )
 //
 void BoardViewBase::slot_open_tab()
 {
-    if( ! m_path_selected.empty() ) open_row( m_path_selected, true );
+    if( ! m_path_selected.empty() ) open_row( m_path_selected, true, false );
+}
+
+
+//
+// popupmenu でスレ情報を消さずに再取得を選択
+//
+void BoardViewBase::slot_reget_article()
+{
+    if( ! m_path_selected.empty() ) open_row( m_path_selected, true, true );
 }
 
 
@@ -2359,13 +2381,15 @@ void BoardViewBase::slot_open_browser()
 
 
 //
-// 記事を開く 
+// 記事を開く
 //
-const bool BoardViewBase::open_row( Gtk::TreePath& path, const bool tab )
+const bool BoardViewBase::open_row( Gtk::TreePath& path, const bool tab, const bool reget )
 {
     std::string str_tab = "false";
     if( tab ) str_tab = "true";
 
+    std::string mode = std::string();;
+
     const std::string url_target = path2daturl( path );
 
 #ifdef _DEBUG
@@ -2374,11 +2398,36 @@ const bool BoardViewBase::open_row( Gtk::TreePath& path, const bool tab )
 
     if( url_target.empty() ) return false;
 
+    if( reget ){
+
+        if( ! SESSION::is_online() ){
+            SKELETON::MsgDiag mdiag( get_parent_win(), "オフラインです" );
+            mdiag.run();
+            return false;
+        }
+
+        if( ! DBTREE::article_is_cached( url_target ) ) return false;
+
+        if( DBTREE::article_status( url_target ) & STATUS_OLD ){
+            SKELETON::MsgDiag mdiag( get_parent_win(),
+                                     "DAT落ちしています。\n\nログが消える恐れがあります。実行しますか？",
+                                     false, Gtk::MESSAGE_QUESTION, Gtk::BUTTONS_YES_NO );
+            mdiag.set_default_response( Gtk::RESPONSE_NO );
+            if( mdiag.run() != Gtk::RESPONSE_YES ) return false;
+        }
+
+        mode = "reget";
+    }
+
     // datロード終了時に次スレ移行チェックを行う
     DBTREE::article_set_url_pre_article( url_target, get_url_pre_article() );
 
-    const std::string mode = std::string();
     CORE::core_set_command( "open_article", url_target, str_tab, mode );
+
+    // 行を長押ししてから素早くクリックし直すとslot_button_press()が呼び出されて
+    // スレビューが表示されてから一瞬スレ一覧に切り替わるのを防ぐ
+    m_cancel_openrow_counter = CANCEL_OPENROW / TIMER_TIMEOUT;
+
     return true;
 }
 
@@ -2387,30 +2436,66 @@ const bool BoardViewBase::open_row( Gtk::TreePath& path, const bool tab )
 //
 // 選択した行をまとめて開く
 //
-void BoardViewBase::open_selected_rows()
+void BoardViewBase::open_selected_rows( const bool reget )
 {
+    std::string mode = std::string();;
     std::string list_url;
     std::list< Gtk::TreeModel::iterator > list_it = m_treeview.get_selected_iterators();
-    std::list< Gtk::TreeModel::iterator >::iterator it = list_it.begin();
+    std::list< Gtk::TreeModel::iterator >::iterator it;
+
+    if( reget ){
+
+        if( ! SESSION::is_online() ){
+            SKELETON::MsgDiag mdiag( get_parent_win(), "オフラインです" );
+            mdiag.run();
+            return;
+        }
+
+        it = list_it.begin();
+        for( ; it != list_it.end(); ++it ){
+
+            Gtk::TreeModel::Row row = *( *it );
+            DBTREE::ArticleBase *art = row[ m_columns.m_col_article ];
+
+            if( ! art->is_cached() ) continue;
+
+            if( art->get_status() & STATUS_OLD ){
+                SKELETON::MsgDiag mdiag( get_parent_win(),
+                                         "DAT落ちしているスレを含んでいます。\n\nログが消える恐れがあります。実行しますか？",
+                                         false, Gtk::MESSAGE_QUESTION, Gtk::BUTTONS_YES_NO );
+                mdiag.set_default_response( Gtk::RESPONSE_NO );
+                if( mdiag.run() != Gtk::RESPONSE_YES ) return;
+
+                break;
+            }
+        }
+
+        mode = "reget";
+    }
+
+    it = list_it.begin();
     for( ; it != list_it.end(); ++it ){
 
         if( !list_url.empty() ) list_url += " ";
 
         Gtk::TreeModel::Row row = *( *it );
         DBTREE::ArticleBase *art = row[ m_columns.m_col_article ];
+
+        if( reget && ! art->is_cached() ) continue;
+
         list_url += art->get_url();
 
         // datロード終了時に次スレ移行チェックを行う
         art->set_url_pre_article( get_url_pre_article() );
     }
 
-    CORE::core_set_command( "open_article_list", std::string(), list_url );
+    if( list_url.size() ) CORE::core_set_command( "open_article_list", std::string(), list_url, mode );
 }
 
 
 //
 // path -> スレッドの(dat型)URL変換
-// 
+//
 const std::string BoardViewBase::path2daturl( const Gtk::TreePath& path )
 {
     Gtk::TreeModel::Row row = m_treeview.get_row( path );
@@ -2423,7 +2508,7 @@ const std::string BoardViewBase::path2daturl( const Gtk::TreePath& path )
 
 //
 // path -> 板URL変換
-// 
+//
 const std::string BoardViewBase::path2url_board( const Gtk::TreePath& path )
 {
     if( ! get_url_board().empty() ) return get_url_board();
@@ -2435,7 +2520,7 @@ const std::string BoardViewBase::path2url_board( const Gtk::TreePath& path )
 //
 // 抽出
 //
-const bool BoardViewBase::drawout()
+const bool BoardViewBase::drawout( const bool force_reset )
 {
     int hit = 0;
     bool reset = false;
@@ -2443,7 +2528,7 @@ const bool BoardViewBase::drawout()
     const std::string query = get_search_query();
 
     // 空の時はリセット
-    if( query.empty() ) reset = true;
+    if( force_reset || query.empty() ) reset = true;
 
 #ifdef _DEBUG
     std::cout << "BoardViewBase::drawout query = " <<  query << std::endl;
@@ -2452,10 +2537,15 @@ const bool BoardViewBase::drawout()
     unsorted_column();
 
     JDLIB::Regex regex;
+    const bool icase = true; // 大文字小文字区別しない
+    const bool newline = true; // . に改行をマッチさせない
+    const bool usemigemo = true; // migemo使用
+    const bool wchar = true;  // 全角半角の区別をしない
+
     Gtk::TreeModel::Children child = m_liststore->children();
     Gtk::TreeModel::Children::iterator it = child.begin();
 
-    if ( ! reset ) regex.compile( query, true, true, true );
+    if ( ! reset ) regex.compile( query, icase, newline, usemigemo, wchar );
 
     for( ; it != child.end() ; ++it ){
 
@@ -2498,7 +2588,7 @@ void BoardViewBase::set_search_query( const std::string& query )
 #endif
 
     if( CONFIG::get_inc_search_board() ){
-        drawout();
+        drawout( false );
         m_pre_query = std::string();
     }
 }
@@ -2511,7 +2601,7 @@ void BoardViewBase::exec_search()
 {
     const std::string query = get_search_query();
     if( m_pre_query != query ){
-        drawout();
+        drawout( false );
         focus_view();
         m_pre_query = query;
         CORE::get_completion_manager()->set_query( CORE::COMP_SEARCH_BOARD, query );
@@ -2520,7 +2610,7 @@ void BoardViewBase::exec_search()
 
     focus_view();
     if( query.empty() ) return;
-   
+
     Gtk::TreePath path = m_treeview.get_current_path();;
     if( path.empty() ){
         if( m_search_invert ) path = GET_PATH( *( m_liststore->children().begin() ) );
@@ -2528,12 +2618,17 @@ void BoardViewBase::exec_search()
     }
 
     Gtk::TreePath path_start = path;
-    JDLIB::Regex regex; 
+    JDLIB::Regex regex;
+    const size_t offset = 0;
+    const bool icase = true; // 大文字小文字区別しない
+    const bool newline = true; // . に改行をマッチさせない
+    const bool usemigemo = true; // migemo使用
+    const bool wchar = true;  // 全角半角の区別をしない
 
 #ifdef _DEBUG
     std::cout << "BoardViewBase::search start = " << path_start.to_string() << " query = " <<  query << std::endl;
 #endif
-    
+
     for(;;){
 
         if( !m_search_invert ){
@@ -2550,11 +2645,11 @@ void BoardViewBase::exec_search()
             }
         }
 
-        
+
         if( path == path_start ) break;
-        
+
         Glib::ustring subject = get_name_of_cell( path, m_columns.m_col_subject );
-        if( regex.exec( query, subject, 0, true, true, true ) ){
+        if( regex.exec( query, subject, offset, icase, newline, usemigemo, wchar ) ){
             m_treeview.scroll_to_row( path, 0 );
             m_treeview.set_cursor( path );
             return;
@@ -2590,7 +2685,18 @@ void BoardViewBase::operate_search( const std::string& controlid )
     const int id = atoi( controlid.c_str() );
 
     if( id == CONTROL::Cancel ) focus_view();
-    else if( id == CONTROL::SearchCache ) CORE::core_set_command( "open_article_searchlog", get_url_board() , get_search_query() );
+    else if( id == CONTROL::SearchCache ) CORE::core_set_command( "open_article_searchlog", get_url_board() , get_search_query(), "exec" );
+}
+
+
+//
+// ハイライト解除
+//
+void BoardViewBase::clear_highlight()
+{
+    drawout( true );
+    focus_view();
+    m_pre_query = std::string();
 }
 
 
@@ -2681,7 +2787,7 @@ void BoardViewBase::slot_save_dat()
     std::string path_dir = MISC::recover_path( diag.get_filename() );
     if( path_dir.empty() ) return;
     if( path_dir.c_str()[ path_dir.length()-1 ] != '/' ) path_dir += "/";
-        
+
 #ifdef _DEBUG
     std::cout << "dir = " << path_dir << std::endl;
 #endif
@@ -2857,7 +2963,7 @@ void BoardViewBase::set_article_to_buffer()
 
             list_info.push_back( info );
 
-#ifdef _DEBUG    
+#ifdef _DEBUG
             std::cout << "append " << info.name << std::endl;
 #endif
             path.next();
@@ -2925,7 +3031,7 @@ void BoardViewBase::draw_bg_articles()
 #endif
 
     unsorted_column();
-    
+
     std::list< std::string >::const_iterator it = m_list_draw_bg_articles.begin();
     for( ; it != m_list_draw_bg_articles.end(); ++it ){
 
@@ -2933,7 +3039,7 @@ void BoardViewBase::draw_bg_articles()
 
 #ifdef _DEBUG
         std::cout << url << std::endl;
-#endif    
+#endif
 
         Gtk::TreeModel::Row row = get_row_from_url( url );
 
