@@ -11,6 +11,8 @@
 #include "columns.h"
 
 #include <gtkmm.h>
+#include <ctime>
+
 
 namespace SKELETON
 {
@@ -25,17 +27,6 @@ namespace DBTREE
 namespace BOARD
 {
 
-    enum
-    {
-        SORTMODE_ASCEND = 0,
-        SORTMODE_DESCEND,
-
-        SORTMODE_MARK1, // 通常
-        SORTMODE_MARK2, // 新着をキャッシュの上に。後は通常
-        SORTMODE_MARK3  // 反転
-    };
-
-
     class BoardViewBase : public SKELETON::View
     {
         // viewに表示するboardのURL ( SKELETON::View::m_url はview自身のURLなのに注意すること )
@@ -45,21 +36,26 @@ namespace BOARD
         BOARD::TreeColumns m_columns;
         Glib::RefPtr< Gtk::ListStore > m_liststore;
         Gtk::ScrolledWindow m_scrwin;
-        int m_id;
 
         // 列
         Gtk::TreeView::Column* m_col_mark;
         Gtk::TreeView::Column* m_col_id;
+        Gtk::TreeView::Column* m_col_board;
         Gtk::TreeView::Column* m_col_subject;
         Gtk::TreeView::Column* m_col_res;
         Gtk::TreeView::Column* m_col_str_load;        
         Gtk::TreeView::Column* m_col_str_new;
         Gtk::TreeView::Column* m_col_since;
         Gtk::TreeView::Column* m_col_write;
+        Gtk::TreeView::Column* m_col_access;
         Gtk::TreeView::Column* m_col_speed;
+        Gtk::TreeView::Column* m_col_diff;
+
+        // クリック状態
+        bool m_clicked;
 
         // ダブルクリック状態
-        bool m_dblclick;
+        bool m_dblclicked;
 
         // 押したキー
         int m_pressed_key;
@@ -87,15 +83,38 @@ namespace BOARD
         // draw_bg_articles() を参照せよ
         std::list< std::string > m_list_draw_bg_articles;
 
+        // ポップアップメニュー表示のときにactivate_act_before_popupmenu()で使う変数
+        bool m_enable_menuslot;
+
+        // subject.txt をロードする
+        bool m_load_subject_txt;
+
+        // 先頭に「板」列を表示
+        bool m_show_col_board;
+
+        // 増分行が表示されている
+        bool m_col_diff_is_shown;
+
+        // 連続クリック防止用カウンタ
+        int m_cancel_openrow_counter;
+
     public:
 
-        BoardViewBase( const std::string& url );
+        BoardViewBase( const std::string& url, const bool show_col_board );
         virtual ~BoardViewBase();
 
         const std::string& get_url_board() const { return m_url_board; }
         virtual const std::string url_for_copy();
 
+        // 行数
+        const int get_row_size();
+
         // SKELETON::View の関数のオーバロード
+
+        virtual void save_session(){}
+
+        virtual void update_url( const std::string& url_old, const std::string& url_new );
+
         virtual const int get_icon( const std::string& iconname );
         virtual const bool is_loading(){ return m_loading; }
         virtual const bool set_command( const std::string& command,
@@ -105,6 +124,9 @@ namespace BOARD
 
         virtual void clock_in();
 
+        // キーを押した        
+        virtual const bool slot_key_press( GdkEventKey* event );
+
         virtual void write();
         virtual void stop();
         virtual void show_view();
@@ -115,11 +137,18 @@ namespace BOARD
         virtual void close_view();
         virtual void delete_view();
         virtual void set_favorite();
+
+
+        // 特定の行だけの表示内容更新
+        // url : subject.txt のアドレス
+        // id : DAT の ID(拡張子付き)
+        // もし ID が empty() なら全ての行の表示内容を更新する
         virtual void update_item( const std::string& url, const std::string& id );
+
         virtual const bool operate_view( const int control );
         virtual void goto_top();
         virtual void goto_bottom();
-        virtual void goto_num( int num );
+        virtual void goto_num( const int num_to, const int num_from );
         virtual void scroll_left();
         virtual void scroll_right();
         virtual void show_preference();
@@ -134,6 +163,7 @@ namespace BOARD
         virtual void down_search();
         virtual void operate_search( const std::string& controlid );
         virtual void set_search_query( const std::string& query );
+        void clear_highlight();
 
         void row_up();
         void row_down();
@@ -142,22 +172,48 @@ namespace BOARD
 
       protected:
 
+        // 自動ソート抑制
+        void unsorted_column();
+
+        // url から row を取得
+        Gtk::TreeModel::Row get_row_from_url( const std::string& url );
+
         SKELETON::DragTreeView& get_treeview(){ return m_treeview; }
 
         // Viewが所属するAdminクラス
         virtual SKELETON::Admin* get_admin();
 
+        // ポップアップメニューを表示する前にメニューのアクティブ状態を切り替える
+        virtual void activate_act_before_popupmenu( const std::string& url );
+
+        // ポップアップメニュー取得
         virtual Gtk::Menu* get_popupmenu( const std::string& url );
 
-        void update_view_impl( std::list< DBTREE::ArticleBase* >& list_subject );
+        // view更新
+        void update_view_impl( const std::vector< DBTREE::ArticleBase* >& list_article, const bool loading_fin );
 
-        // ソート状態回復
-        void restore_sort();
+        // ステータスバー更新
+        void update_status();
+
+        // subject.txt をロードする
+        void set_load_subject_txt( const bool load ){ m_load_subject_txt = load; }
+
+        // 行を作って内容をセット
+        const Gtk::TreeModel::Row prepend_row( DBTREE::ArticleBase* art, const int id );
+
+        // デフォルトのソート状態
+        virtual const int get_default_sort_column();
+        virtual const int get_default_view_sort_mode();
+        virtual const int get_default_view_sort_pre_column();
+        virtual const int get_default_view_sort_pre_mode();
 
     private:
 
-        // url から row を取得
-        Gtk::TreeModel::Row get_row_from_url( const std::string& url );
+        void setup_action();
+
+        // 通常の右クリックメニューの作成
+        const std::string create_context_menu();
+        const char* get_menu_item( const int item );
 
         // 次スレ移行処理に使用する前スレのアドレス
         // BOARD::BoardViewNext と BoardViewBase::open_row()を参照せよ
@@ -175,8 +231,16 @@ namespace BOARD
 
         void slot_cell_data( Gtk::CellRenderer* cell, const Gtk::TreeModel::iterator& it );
 
-        // ソート用
+        // 全ての行の表示内容更新
+        void update_item_all();
+
+        // ソート実行
         void exec_sort();
+
+        // ソート状態回復
+        void restore_sort();
+
+        // ヘッダをクリックしたときのslot関数
         void slot_col_clicked( const int col );
 
         const int compare_drawbg( Gtk::TreeModel::Row& row_a, Gtk::TreeModel::Row& row_b );
@@ -187,12 +251,12 @@ namespace BOARD
         const bool slot_button_press( GdkEventButton* event );
         const bool slot_button_release( GdkEventButton* event );
         const bool slot_motion_notify( GdkEventMotion* event );
-        const bool slot_key_press( GdkEventKey* event );
         const bool slot_key_release( GdkEventKey* event );
         const bool slot_scroll_event( GdkEventScroll* event );
 
         void slot_bookmark( int bookmark );
         void slot_open_tab();
+        void slot_reget_article();
         void slot_favorite_thread();
         void slot_favorite_board();
         void slot_copy_url();
@@ -201,7 +265,8 @@ namespace BOARD
         void slot_open_browser();
         void slot_preferences_article();
         void slot_save_dat();
-        void slot_abone_thread();
+        void slot_search_next();
+        virtual void slot_abone_thread();
         void slot_delete_logs();
 
         // ドラッグアンドドロップ
@@ -209,17 +274,15 @@ namespace BOARD
                                  Gtk::SelectionData& selection_data, guint info, guint time );
         void slot_dropped_url_list( const std::list< std::string >& );
 
-        const bool open_row( Gtk::TreePath& path, const bool tab );
-        void open_selected_rows();
+        const bool open_row( Gtk::TreePath& path, const bool tab, const bool reget );
+        void open_selected_rows( const bool reget );
         const std::string path2daturl( const Gtk::TreePath& path );
+        const std::string path2url_board( const Gtk::TreePath& path );
 
         // 検索
-        const bool drawout();
+        const bool drawout( const bool force_reset );
 
-        // 行を作って内容をセット
-        Gtk::TreeModel::Row prepend_row( DBTREE::ArticleBase* art );
-
-        void update_row_common( DBTREE::ArticleBase* art, Gtk::TreeModel::Row& row );
+        void update_row_common( const Gtk::TreeModel::Row& row );
         const std::string get_subject_from_path( Gtk::TreePath& path );
 
         template < typename ColumnType >
