@@ -12,6 +12,7 @@
 
 #include "jdlib/miscutil.h"
 #include "jdlib/miscmsg.h"
+#include "jdlib/misctime.h"
 
 #include "dbtree/interface.h"
 
@@ -26,6 +27,9 @@
 
 #include <fcntl.h>
 #include <cstring>
+#if defined(_WIN32)
+#include <utime.h>
+#endif
 
 enum
 {
@@ -66,6 +70,9 @@ std::string CACHE::path_session()
 // ロックファイル
 std::string CACHE::path_lock()
 {
+    const std::string jd_lock = MISC::getenv_limited( "JD_LOCK", MAX_SAFE_PATH );
+    if( ! jd_lock.empty() ) return jd_lock;
+
     return CACHE::path_root() + "JDLOCK";
 }
 
@@ -162,11 +169,6 @@ std::string CACHE::path_xml_history()
 {
     return CACHE::path_root() +  "hist.xml";
 }
-// 1.9.5-beta070611以前
-std::string CACHE::path_xml_history_old()
-{
-    return CACHE::path_root() +  "history.xml";
-}
 
 
 // 板履歴
@@ -174,11 +176,6 @@ std::string CACHE::path_xml_history_board()
 {
     return CACHE::path_root() +  "hist_board.xml";
 }
-// 1.9.5-beta070611以前
-std::string CACHE::path_xml_history_board_old()
-{
-    return CACHE::path_root() +  "history_board.xml";
-}
 
 
 // 最近閉じたスレの履歴
@@ -186,10 +183,17 @@ std::string CACHE::path_xml_history_close()
 {
     return CACHE::path_root() +  "hist_close.xml";
 }
-// 1.9.5-beta070611以前
-std::string CACHE::path_xml_history_close_old()
+
+// 最近閉じた板の履歴
+std::string CACHE::path_xml_history_closeboard()
 {
-    return CACHE::path_root() +  "history_close.xml";
+    return CACHE::path_root() +  "hist_closeboard.xml";
+}
+
+// 最近閉じた画像の履歴
+std::string CACHE::path_xml_history_closeimg()
+{
+    return CACHE::path_root() +  "hist_closeimg.xml";
 }
 
 
@@ -492,12 +496,29 @@ std::string CACHE::path_aahistory()
 }
 
 
+//
+// テーマのルートパス
+//
+const std::string CACHE::path_theme_root()
+{
+    return CACHE::path_root() + "theme/";
+}
+
+//
+// アイコンテーマのルートパス
+//
+const std::string CACHE::path_theme_icon_root()
+{
+    return CACHE::path_theme_root() + "icons/";
+}
+
+
 //
 // css
 //
 std::string CACHE::path_css()
 {
-    return CACHE::path_root() +  "jd.css";
+    return CACHE::path_theme_root() +  "jd.css";
 }
 
 
@@ -505,6 +526,24 @@ std::string CACHE::path_css()
 // res.html
 //
 std::string CACHE::path_reshtml()
+{
+    return CACHE::path_theme_root() +  "Res.html";
+}
+
+
+//
+// css (旧バージョンとの互換性のため)
+//
+std::string CACHE::path_css_old()
+{
+    return CACHE::path_root() +  "jd.css";
+}
+
+
+//
+// res.html (旧バージョンとの互換性のため)
+//
+std::string CACHE::path_reshtml_old()
 {
     return CACHE::path_root() +  "Res.html";
 }
@@ -768,6 +807,42 @@ time_t CACHE::get_filemtime( const std::string& path )
 }
 
 
+const bool CACHE::set_filemtime( const std::string& path, const time_t mtime )
+{
+#ifdef _DEBUG
+    std::cout << "CACHE::set_filemtime path = " << path
+              << " mtime = " << MISC::timettostr( mtime, MISC::TIME_NORMAL ) << std::endl;
+#endif
+
+    struct stat buf_stat;
+
+    if( stat( to_locale_cstr( path ), &buf_stat ) != 0 ) return false;
+    if( S_ISREG( buf_stat.st_mode ) ){
+
+#if defined(_WIN32)
+        struct utimbuf tb;
+
+        tb.actime = buf_stat.st_atime;
+        tb.modtime = mtime;
+
+        if( ! utime( to_locale_cstr( path ), &tb ) ) return true;
+
+#else // WIN32
+        struct timeval tv[2];
+
+        tv[0].tv_sec  = buf_stat.st_atime;
+        tv[0].tv_usec = 0;
+        tv[1].tv_sec  = mtime;
+        tv[1].tv_usec = 0;
+
+        if( ! utimes( to_locale_cstr( path ), tv ) ) return true;
+#endif // WIN32
+    }
+
+    return false;
+}
+
+
 //
 // mkdir
 //
@@ -1072,9 +1147,9 @@ std::list< std::string > CACHE::get_filelist( const std::string& dir )
 //
 // dir ディレクトリ内のレギュラーファイルの合計サイズを取得
 //
-int64_t CACHE::get_dirsize( const std::string& dir )
+guint64 CACHE::get_dirsize( const std::string& dir )
 {
-    int64_t total_size = 0;
+    guint64 total_size = 0;
 
 #ifdef _DEBUG
     std::cout << "CACHE::get_dirsize " << dir << std::endl;
@@ -1107,6 +1182,7 @@ const std::string CACHE::get_realpath( const std::string& path )
 
     char resolved_path[ PATH_MAX + 1 ];
 #ifdef _WIN32
+    // _fullpath() are not checked　the path is completely available
     char* ret = _fullpath( resolved_path, to_locale_cstr( path ), PATH_MAX );
 #else
     char* ret = realpath( to_locale_cstr( path ), resolved_path );
@@ -1116,7 +1192,9 @@ const std::string CACHE::get_realpath( const std::string& path )
     }
     else return std::string();
 
-    if( CACHE::file_exists( path_real ) == EXIST ) return std::string();
+    if( CACHE::file_exists( path_real ) == EXIST_ERROR ){
+        return std::string();
+    }
 
 #ifdef _DEBUG
     std::cout << "CACHE::get_realpath path = " << path
