@@ -138,6 +138,7 @@ const std::string& CONFIG::get_url_login2ch() { return get_confitem()->url_login
 
 // p2の認証サーバのアドレス
 const std::string& CONFIG::get_url_loginp2() { return get_confitem()->url_loginp2; }
+void CONFIG::set_url_loginp2( const std::string& url ) { get_confitem()->url_loginp2 = url; }
 
 // BEの認証サーバのアドレス
 const std::string& CONFIG::get_url_loginbe() { return get_confitem()->url_loginbe; }
@@ -421,6 +422,9 @@ const bool CONFIG::get_show_tab_icon(){ return get_confitem()->show_tab_icon; }
 // タブ上でマウスホイールを回転してタブを切り替える
 const bool CONFIG::get_switchtab_wheel(){ return get_confitem()->switchtab_wheel; }
 
+// ビュー内から他のビューを開いたときのタブの位置 ( 0: 一番右端 1:右隣 2:左隣 )
+const int CONFIG::get_newtab_pos(){  return get_confitem()->newtab_pos; }
+
 const bool CONFIG::get_show_post_mark(){ return get_confitem()->show_post_mark; }
 void CONFIG::set_show_post_mark( const bool show ){ get_confitem()->show_post_mark = show; }
 
