@@ -36,6 +36,8 @@ namespace CONTROL
 #define KEYCONF_TabNum8 "Alt+8"
 #define KEYCONF_TabNum9 "Alt+9"
 
+#define KEYCONF_RestoreLastTab "Ctrl+T"
+
 #define KEYCONF_PreBookMark  "Ctrl+F2"
 #define KEYCONF_NextBookMark  "F2"
 
@@ -79,11 +81,14 @@ namespace CONTROL
 #define KEYCONF_SearchInvert  "?"
 #define KEYCONF_SearchNext  "Enter F3 Ctrl+g"
 #define KEYCONF_SearchPrev  "Shift+Enter Ctrl+F3 Ctrl+G N"
+#define KEYCONF_SearchTitle "Ctrl+t"
 #define KEYCONF_DrawOutAnd  "Ctrl+Enter"
 
 #define KEYCONF_CheckUpdateRoot ""
 #define KEYCONF_CheckUpdateOpenRoot ""
 
+#define KEYCONF_FullScreen "F11"
+
 // BBSLIST
 #define KEYCONF_OpenBoard  "Space"
 #define KEYCONF_OpenBoardTab  "Ctrl+Space"
@@ -117,7 +122,6 @@ namespace CONTROL
 
 #define KEYCONF_SearchNextArticle "Ctrl+Space"
 #define KEYCONF_SearchWeb "Ctrl+k"
-#define KEYCONF_SearchTitle "Ctrl+t"
 #define KEYCONF_SearchCacheLocal "Ctrl+Enter"
 #define KEYCONF_SearchCacheAll ""
 
@@ -138,6 +142,7 @@ namespace CONTROL
 #define KEYCONF_ExecWrite  "Alt+w" 
 
 #define KEYCONF_FocusWrite  "Tab" 
+#define KEYCONF_ToggleSage  "Alt+s" 
 
 // EDIT
 #define KEYCONF_HomeEdit  ""
@@ -151,6 +156,7 @@ namespace CONTROL
 #define KEYCONF_DeleteEdit  ""
 #define KEYCONF_BackspEdit  ""
 #define KEYCONF_UndoEdit  "Ctrl+/ Ctrl+z"
+#define KEYCONF_EnterEdit  ""
 
 #define KEYCONF_InputAA  "Alt+a"
 
@@ -179,6 +185,8 @@ namespace CONTROL
 #define MOUSECONF_CloseAllTabs ""
 #define MOUSECONF_CloseOtherTabs ""
 
+#define MOUSECONF_RestoreLastTab "64"
+
 #define MOUSECONF_CheckUpdateTabs ""
 
 #define MOUSECONF_ToggleArticle "2"
@@ -189,12 +197,15 @@ namespace CONTROL
 #define MOUSECONF_End "62"
 #define MOUSECONF_Quit "26"
 #define MOUSECONF_Reload "82"
+#define MOUSECONF_Delete "262"
 #define MOUSECONF_StopLoading "8"
 #define MOUSECONF_AppendFavorite  ""
 
 #define MOUSECONF_NewArticle "24"
 #define MOUSECONF_WriteMessage "24"
 
+#define MOUSECONF_SearchTitle ""
+
 #define MOUSECONF_CheckUpdateRoot "48"
 #define MOUSECONF_CheckUpdateOpenRoot "42"
 
@@ -206,7 +217,6 @@ namespace CONTROL
 #define MOUSECONF_GotoNew "626"
 #define MOUSECONF_SearchNextArticle "28"
 #define MOUSECONF_SearchWeb ""
-#define MOUSECONF_SearchTitle ""
 #define MOUSECONF_LiveStartStop ""
 
 // IMAGE
