@@ -15,6 +15,8 @@
 #include "jdlib/jdregex.h"
 #include "jdlib/tfidf.h"
 
+#include "dbimg/imginterface.h"
+
 #include "config/globalconf.h"
 
 #include "httpcode.h"
@@ -68,20 +70,23 @@ ArticleBase::ArticleBase( const std::string& datbase, const std::string& id, boo
       m_status( STATUS_UNKNOWN ),
       m_subject( std::string() ),
       m_number( 0 ),
+      m_number_diff( 0 ),
       m_number_new( 0 ),
       m_number_load( 0 ),
       m_number_before_load( 0 ),
       m_number_seen( 0 ),
-      m_number_max( MAX_RESNUMBER ),
+      m_number_max( 0 ),
       m_write_fixname( 0 ),
       m_write_fixmail( 0 ),
       m_abone_transparent( false ),
       m_abone_chain( false ),
       m_abone_age( false ),
+      m_abone_board( true ),
+      m_abone_global( true ),
       m_bookmarked_thread( false ),
       m_cached( cached ),
       m_read_info( 0 ),
-      m_save_info( 0 ),
+      m_save_info( false ),
       m_924( false )
 {
 #ifdef _DEBUG
@@ -319,7 +324,7 @@ std::list< int > ArticleBase::get_res_with_url()
 //
 // mode_or == true なら OR抽出
 //
-std::list< int > ArticleBase::get_res_query( const std::string& query, bool mode_or )
+const std::list< int > ArticleBase::get_res_query( const std::string& query, const bool mode_or )
 {
     if( empty() ){ std::list< int > tmp; return tmp; }
 
@@ -427,6 +432,24 @@ const std::string ArticleBase::get_access_time_str()
 }
 
 
+//
+// ユーザが最後にロードした月日( string型 )
+//
+const std::string& ArticleBase::get_access_date()
+{
+    if( m_access_time.tv_sec ){
+
+        if( m_access_date.empty() 
+            || SESSION::get_col_write_time() == MISC::TIME_PASSED ){
+        
+        	m_access_date = MISC::timettostr( m_access_time.tv_sec, SESSION::get_col_write_time() );
+        }
+    }
+
+    return m_access_date;
+}
+
+
 void ArticleBase::reset_status()
 {
 #ifdef _DEBUG
@@ -463,10 +486,12 @@ void ArticleBase::set_number( const int number, const bool is_online )
 {
     if( ! number ) return;
 
+    m_number_diff = 0;
     m_status &= ~STATUS_BROKEN_SUBJECT;
 
     if( number > m_number ){
 
+        m_number_diff = number - m_number;
         m_number = number;
 
         // キャッシュがあって更新可能になった場合は
@@ -526,6 +551,7 @@ void ArticleBase::update_writetime()
     if( CONFIG::get_save_post_history() && gettimeofday( &tv, &tz ) == 0 ){
 
         m_write_time = tv;
+        m_write_time_date = std::string();
 
 #ifdef _DEBUG
         std::cout << "ArticleBase::update_writetime : " << m_write_time.tv_sec << " " << m_write_time_date << std::endl;
@@ -581,11 +607,16 @@ const bool ArticleBase::enable_load()
 //
 const bool ArticleBase::is_finished()
 {
+    if( is_cached() && ! enable_load() &&  m_number_max && get_number_seen() >= m_number_max ){
+
 #ifdef _DEBUG
-    if( get_number_seen() >= get_number_max() ) std::cout << is_cached() << " " << !enable_load() << " " << get_number_seen() << " " << get_subject() << std::endl;
+        std::cout << "ArticleBase::is_finished :  seen = " << get_number_seen() << " max = " << m_number_max << " : " << get_subject() << std::endl;
 #endif
 
-    return ( is_cached() && ! enable_load() && get_number_seen() >= get_number_max() );
+        return true;
+    }
+
+    return false;
 }
 
 
@@ -634,7 +665,7 @@ void ArticleBase::update_abone()
     if( ! m_nodetree ) return;
 
     get_nodetree()->copy_abone_info( m_list_abone_id, m_list_abone_name, m_list_abone_word, m_list_abone_regex, m_vec_abone_res,
-                                     m_abone_transparent, m_abone_chain, m_abone_age );
+                                     m_abone_transparent, m_abone_chain, m_abone_age, m_abone_board, m_abone_global );
 
     get_nodetree()->update_abone_all();
 }
@@ -649,7 +680,9 @@ void ArticleBase::reset_abone( const std::list< std::string >& ids,
                                const std::list< std::string >& words,
                                const std::list< std::string >& regexs,
                                const std::vector< char >& vec_abone_res,
-                               const bool transparent, const bool chain, const bool age )
+                               const bool transparent, const bool chain, const bool age,
+                               const bool board, const bool global
+    )
 {
     if( empty() ) return;
 
@@ -684,6 +717,8 @@ void ArticleBase::reset_abone( const std::list< std::string >& ids,
     m_abone_transparent = transparent;
     m_abone_chain = chain;
     m_abone_age = age;
+    m_abone_board = board;
+    m_abone_global = global;
 
     update_abone();
 
@@ -765,7 +800,7 @@ void ArticleBase::set_abone_res( const int num_from, const int num_to, const boo
     if( num_from <= 0 || num_to >= MAX_RESNUMBER ) return;
 
 #ifdef _DEBUG
-    std::cout << "ArticleBase::set_abone_res num = " << number << " set = " << set << std::endl;
+    std::cout << "ArticleBase::set_abone_res num_from = " << num_from << " num_to = " << num_to << " set = " << set << std::endl;
 #endif    
 
     if( ! m_vec_abone_res.size() ) m_vec_abone_res.resize( MAX_RESNUMBER );
@@ -824,6 +859,36 @@ void ArticleBase::set_abone_age( const bool set )
 } 
 
 
+//
+// 板レベルでのあぼーんを有効にする
+//
+void ArticleBase::set_abone_board( const bool set )
+{
+    if( empty() ) return;
+
+    m_abone_board = set;
+
+    update_abone();
+
+    m_save_info = true;
+} 
+
+
+//
+// 全体レベルでのあぼーんを有効にする
+//
+void ArticleBase::set_abone_global( const bool set )
+{
+    if( empty() ) return;
+
+    m_abone_global = set;
+
+    update_abone();
+
+    m_save_info = true;
+} 
+
+
 //
 // ブックマークの数
 //
@@ -944,7 +1009,7 @@ JDLIB::ConstPtr< NodeTreeBase >& ArticleBase::get_nodetree()
 
         // あぼーん情報のコピー
         m_nodetree->copy_abone_info( m_list_abone_id, m_list_abone_name, m_list_abone_word, m_list_abone_regex, m_vec_abone_res,
-                                     m_abone_transparent, m_abone_chain, m_abone_age );
+                                     m_abone_transparent, m_abone_chain, m_abone_age, m_abone_board, m_abone_global );
 
         // 書き込み情報のコピー
         m_nodetree->copy_post_info( m_vec_posted );
@@ -976,10 +1041,11 @@ void ArticleBase::unlock_impl()
 #endif
 
     m_nodetree->terminate_load(); // deleteする前にスレッド停止
-    m_nodetree.clear();
 
-    // スレ情報保存
+    // スレ情報保存 	 
     save_info( false );
+
+    m_nodetree.clear();
 }
 
 
@@ -1048,6 +1114,7 @@ void ArticleBase::download_dat( const bool check_update )
         if( tv.tv_sec ) passed = MAX( 0, tv.tv_sec - m_check_update_time.tv_sec );
 
         if( ! SESSION::is_online()
+            || ! enable_check_update()
             || is_loading()
             || enable_load() // 既に新着あり状態の時はチェックしない
             || ( m_status & STATUS_OLD )
@@ -1059,6 +1126,24 @@ void ArticleBase::download_dat( const bool check_update )
                       << " loading = " << is_loading()
                       << std::endl;
 #endif
+
+            // スレビューのタブとサイドバーのアイコン表示を更新
+
+            // JDが異常終了すると、お気に入りに+が付いてないのにスレが更新可能状態になっていて
+            // 更新チェックが行われてなくなるときがある。このバグは次の様にして再現出来た
+            // (1) 端末からJDを起動する
+            // (2) 適当な板のスレ一覧を開く
+            // (3) お気に入りに適当なスレを登録
+            // (4) そのスレを読み込む。読み込んだらスレビューは閉じないままにしておく
+            // (5) スレ一覧を更新してそのスレに + マークを付ける。お気に入りにも + が付く
+            // (6) そのスレのスレビューを閉じる ( スレ情報を保存 )
+            // (7) 端末で Ctrl+c を押してJDを強制終了
+            // (8) 再起動してお気に入りの復元をしない
+            // (9) お気に入りの + が消えている。以後更新チェックも行われない
+
+            CORE::core_set_command( "toggle_article_icon", m_url);
+            CORE::core_set_command( "toggle_sidebar_articleicon", m_url );
+
             return;
         }
     }
@@ -1149,8 +1234,10 @@ void ArticleBase::copy_article_info( const std::string& url_src )
     const bool transparent = DBTREE::get_abone_transparent( url_src );
     const bool chain = DBTREE::get_abone_chain( url_src );
     const bool age = DBTREE::get_abone_age( url_src );
+    const bool board = DBTREE::get_abone_board( url_src );
+    const bool global = DBTREE::get_abone_global( url_src );
 
-    reset_abone( ids, names ,words, regexs, vec_abone_res, transparent, chain, age );
+    reset_abone( ids, names ,words, regexs, vec_abone_res, transparent, chain, age, board, global );
 }
 
 
@@ -1207,7 +1294,7 @@ void ArticleBase::slot_load_finished()
     if( m_code != HTTP_ERR ){
 
         // DAT落ち
-        if( m_code == HTTP_REDIRECT || m_code == HTTP_NOT_FOUND || m_code == HTTP_OLD ){
+        if( m_code == HTTP_MOVED_PERM || m_code == HTTP_REDIRECT || m_code == HTTP_NOT_FOUND || m_code == HTTP_OLD ){
             m_status &= ~STATUS_NORMAL;
             m_status |= STATUS_OLD;
             CORE::core_set_command( "toggle_sidebar_articleicon", m_url );
@@ -1234,7 +1321,8 @@ void ArticleBase::slot_load_finished()
 #endif
 
         // スレタブとお気に入りとスレ一覧のアイコンに更新マークをつける
-        if( m_code == HTTP_OK || m_code == HTTP_PARTIAL_CONTENT ){
+        if( m_code == HTTP_OK // まちBBSは206が返らない(200か304のみ)
+            || m_code == HTTP_PARTIAL_CONTENT ){
 
             show_updateicon( true );
 
@@ -1348,9 +1436,7 @@ void ArticleBase::slot_load_finished()
                 copy_article_info( m_url_pre_article );
 
                 // お気に入りのアドレスと名前を自動更新
-                if( CONFIG::get_replace_favorite_next() ){
-                    CORE::core_set_command( "replace_favorite_thread", "", m_url_pre_article, m_url );
-                }
+                CORE::core_set_command( "replace_favorite_thread", "", m_url_pre_article, m_url );
 
                 // 前スレにしおりがセットされていたらしおりをつける
                 if( DBTREE::is_bookmarked_thread( m_url_pre_article ) ){
@@ -1375,9 +1461,14 @@ void ArticleBase::slot_load_finished()
 
     else{
 
-        // スレが更新している場合はスレ情報を更新
-        if( m_number_new
+        // スレ情報を更新
+        if( m_number_new // スレが更新している場合
+
             || m_date_modified != m_old_modified // ときどき modified が誤って返るときがあるので最新の値を保存しておく
+
+            || ( SESSION::is_online() && ( m_status & STATUS_UPDATE )
+                 && ( m_code == HTTP_OK || m_code == HTTP_NOT_MODIFIED ) )  // 間違って更新可能マークが付いている場合はマークを消す
+
             ){
 
             m_cached = true;
@@ -1386,7 +1477,10 @@ void ArticleBase::slot_load_finished()
 
             struct timeval tv;
             struct timezone tz;
-            if( gettimeofday( &tv, &tz ) == 0 ) m_access_time = tv;
+            if( gettimeofday( &tv, &tz ) == 0 ) {
+                m_access_time = tv;
+                m_access_date = std::string();
+            }
 
             if( m_number < m_number_load ) m_number = m_number_load;
 
@@ -1452,9 +1546,8 @@ void ArticleBase::show_updateicon( const bool update )
             m_save_info = true;
             m_status |= STATUS_UPDATE;
 
-            // スレビューのタブのアイコン表示を更新
+            // スレビューのタブとサイドバーのアイコン表示を更新
             CORE::core_set_command( "toggle_article_icon", m_url);
-
             CORE::core_set_command( "toggle_sidebar_articleicon", m_url );
         }
     }
@@ -1508,9 +1601,10 @@ void ArticleBase::delete_cache( const bool cache_only )
 
             SKELETON::MsgDiag mdiag( NULL, msg, false, Gtk::MESSAGE_QUESTION, Gtk::BUTTONS_YES_NO );
             mdiag.set_default_response( Gtk::RESPONSE_YES );
-            if( mdiag.run() == Gtk::RESPONSE_NO ) return;
+            if( mdiag.run() != Gtk::RESPONSE_YES ) return;
         }
-        else if( CONFIG::get_show_del_written_thread_diag() && m_write_time.tv_sec ){
+
+        if( CONFIG::get_show_del_written_thread_diag() && m_write_time.tv_sec ){
 
             const std::string msg = "「" + get_subject() + "」には書き込み履歴が残っています。\n\nスレを削除しますか？";
 
@@ -1518,10 +1612,67 @@ void ArticleBase::delete_cache( const bool cache_only )
                                           "今後表示しない(常に削除)(_D)",
                                           Gtk::MESSAGE_QUESTION, Gtk::BUTTONS_YES_NO );
 
-            if( mdiag.run() == Gtk::RESPONSE_NO ) return;
+            if( mdiag.run() != Gtk::RESPONSE_YES ) return;
 
             if( mdiag.get_chkbutton().get_active() ) CONFIG::set_del_written_thread_diag( false );
         }
+
+        // スレ内の画像キャッシュ削除
+        if( CONFIG::get_delete_img_in_thread() != 2 ){
+
+            bool delete_img_cache = false;
+
+            std::list< std::string > list_urls = get_nodetree()->get_urls();
+            std::list< std::string >::iterator it = list_urls.begin();
+            for( ; it != list_urls.end(); ++it ){
+
+                if( DBIMG::get_type_ext( *it ) != DBIMG::T_UNKNOWN && DBIMG::is_cached( *it ) ){
+                    delete_img_cache = true;
+                    break;
+                }
+            }
+
+            if( delete_img_cache ){
+
+                if( CONFIG::get_delete_img_in_thread() == 0 ){
+
+                    const std::string msg = "「" + get_subject() + "」には画像が貼られています。\n\n画像のキャッシュも削除しますか？";
+
+                    SKELETON::MsgCheckDiag mdiag( NULL, msg,
+                                                  "今後表示しない(常に削除しない)(_D)",
+                                                  Gtk::MESSAGE_QUESTION, Gtk::BUTTONS_NONE );
+
+                    mdiag.add_button( "スレ削除中止(_C)", Gtk::RESPONSE_CANCEL );
+                    mdiag.add_button( Gtk::Stock::YES, Gtk::RESPONSE_YES );
+                    Gtk::Button button( Gtk::Stock::NO );
+                    mdiag.add_default_button( &button, Gtk::RESPONSE_NO );
+
+                    const int ret = mdiag.run();
+                    if( ret == Gtk::RESPONSE_CANCEL ) return;
+                    if( ret != Gtk::RESPONSE_YES ){
+
+                        if( mdiag.get_chkbutton().get_active() ) CONFIG::set_delete_img_in_thread( 2 );
+                        delete_img_cache = false;
+                    }
+                }
+
+                if( delete_img_cache ){
+
+                    it = list_urls.begin();
+                    for( ; it != list_urls.end(); ++it ){
+
+                        if( DBIMG::get_type_ext( *it ) != DBIMG::T_UNKNOWN && DBIMG::is_cached( *it ) ){
+
+#ifdef _DEBUG
+                            std::cout << "delete " << *it << std::endl;
+#endif
+                            DBIMG::delete_cache( *it );
+                        }
+                    }
+                }
+
+            }
+        }
     }
 
     m_number_load = m_number_seen = m_number_before_load = 0;
@@ -1554,6 +1705,8 @@ void ArticleBase::delete_cache( const bool cache_only )
         m_abone_transparent = false;
         m_abone_chain = false;
         m_abone_age = false;
+        m_abone_board = true;
+        m_abone_global = true;
         m_read_info = false;
         m_save_info = false;
         m_bookmarked_thread = false;
@@ -1800,6 +1953,16 @@ void ArticleBase::read_info()
                 m_check_update_time.tv_sec = ( atoi( ( *(it_tmp++) ).c_str() ) << 16 ) + atoi( ( *(it_tmp++) ).c_str() );
             }
         }
+
+        // 板レベルでのあぼーんを有効にする
+        m_abone_board = true;
+        GET_INFOVALUE( str_tmp, "aboneboard = " );
+        if( ! str_tmp.empty() ) m_abone_board = atoi( str_tmp.c_str() );
+
+        // 全体レベルでのあぼーんを有効にする
+        m_abone_global = true;
+        GET_INFOVALUE( str_tmp, "aboneglobal = " );
+        if( ! str_tmp.empty() ) m_abone_global = atoi( str_tmp.c_str() );
     }
 
     // キャッシュはあるけど情報ファイルが無い場合
@@ -1844,7 +2007,6 @@ void ArticleBase::read_info()
         m_status |= STATUS_OLD;
         saveinfo = true;
     }
-
     if( saveinfo ) save_info( true );
 
 #ifdef _DEBUG
@@ -1899,15 +2061,20 @@ void ArticleBase::read_info()
 // infoファイル書き込み
 //
 // キャッシュがある( is_cached() == true )　かつ
-// m_save_info = true の時に保存。save_info()を呼ぶ前にm_save_infoをセットすること。
+// m_save_info = true かつ nodetree が作られている時に保存。
+// save_info()を呼ぶ前にm_save_infoをセットすること。
 //
 // キャッシュがあって、force = true の時は強制書き込み
-//
 void ArticleBase::save_info( const bool force )
 {
     if( empty() ) return;
     if( ! is_cached() ) return;
-    if( ! force && ! m_save_info ) return;
+    if( ! force ){
+
+        if( ! m_save_info ) return;
+        if( ! m_nodetree ) return;
+    }
+
     m_save_info = false;
 
     if( m_path_article_ext_info.empty() ) return;
@@ -1977,6 +2144,8 @@ void ArticleBase::save_info( const bool force )
          << "posted = " << ss_posted.str() << std::endl
          << "aboneage = " << m_abone_age << std::endl
          << "checktime = " << ss_check.str() << std::endl
+         << "aboneboard = " << m_abone_board << std::endl
+         << "aboneglobal = " << m_abone_global << std::endl
     ;
 
 #ifdef _DEBUG
