@@ -60,6 +60,7 @@ namespace DBTREE
         int m_number_seen;           // どこまで読んだか
         int m_number_max;            // 規定の最大レス数(0:未設定)
         struct timeval m_access_time;  // ユーザが最後にロードした時間
+        std::string m_access_date;     // ユーザが最後にロードした月日( string型 )
         struct timeval m_check_update_time;  // 最終更新チェック時間
         struct timeval m_write_time;   // 最終書き込み時間
         std::string m_write_time_date; // 最終書き込み月日( string型 )
@@ -77,6 +78,8 @@ namespace DBTREE
         bool m_abone_transparent; // 透明あぼーん
         bool m_abone_chain; // 連鎖あぼーん
         bool m_abone_age; // age ているレスをあぼーん
+        bool m_abone_board; // 板レベルでのあぼーんを有効にする
+        bool m_abone_global; // 全体レベルでのあぼーんを有効にする
 
         // 「スレ」がスレ一覧でブックマークされているか
         bool m_bookmarked_thread;          
@@ -232,6 +235,8 @@ namespace DBTREE
 
         // 最終アクセス時間
         const std::string get_access_time_str();
+        const time_t& get_access_time() const { return m_access_time.tv_sec; } // 秒
+        const std::string& get_access_date(); // string型
 
         // 最終書き込み時間
         const time_t& get_write_time() const { return m_write_time.tv_sec; } // 秒
@@ -316,6 +321,12 @@ namespace DBTREE
         // ageあぼーん
         const bool get_abone_age() const { return m_abone_age; }
 
+        // 板レベルでのあぼーん
+        const bool get_abone_board() const { return m_abone_board; }
+
+        // 全体レベルでのあぼーん
+        const bool get_abone_global() const { return m_abone_global; }        
+
         // number番のレスがあぼーんされているか
         const bool get_abone( int number );
 
@@ -328,7 +339,9 @@ namespace DBTREE
                           const std::list< std::string >& words,
                           const std::list< std::string >& regexs,
                           const std::vector< char >& vec_abone_res,
-                          const bool transparent, const bool chain, const bool age );
+                          const bool transparent, const bool chain, const bool age,
+                          const bool board, const bool global
+            );
 
         // あぼ〜ん状態更新(reset_abone()と違って各項目ごと個別におこなう)
         void add_abone_id( const std::string& id );
@@ -338,6 +351,9 @@ namespace DBTREE
         void set_abone_transparent( const bool set ); // 透明
         void set_abone_chain( const bool set ); // 連鎖
         void set_abone_age( const bool set ); // age
+        void set_abone_board( const bool set ); // 板レベルでのあぼーん
+        void set_abone_global( const bool set ); // 全体レベルでのあぼーん
+
 
         // 「スレ」のブックマーク
         void set_bookmarked_thread( const bool bookmarked );
