@@ -1263,43 +1263,44 @@ const std::string MISC::Iconv( const std::string& str, const std::string& coding
 //
 const int MISC::spchar_number_ln( const char* in_char, int& offset )
 {
-    int lng;
+    int lng = 0;
     offset = 2;
 
     // offset == 2 なら 10 進数、3 なら16進数
     if( in_char[ offset ] == 'x' || in_char[ offset ] == 'X' ) ++offset;
 
-    // 桁数取得(最大4桁)
-    if( in_char[ offset ] == ';' ) return -1;
-    else if( in_char[ offset +1 ] == ';' ) lng = 1;
-    else if( in_char[ offset +2 ] == ';' ) lng = 2;
-    else if( in_char[ offset +3 ] == ';' ) lng = 3;
-    else if( in_char[ offset +4 ] == ';' ) lng = 4;
-    else if( in_char[ offset +5 ] == ';' ) lng = 5;
-    else return -1;
+    // UCS2の2バイトの範囲でデコードするので最大65535
+    // デコードするとき「;」で終端されていなくてもよい
 
     // デコード可能かチェック
-
     // 10 進数
     if( offset == 2 ){
 
-        for( int i = 0; i < lng; ++i ){
-            if( in_char[ offset + i ] < '0' || in_char[ offset + i ] > '9' ) return -1;
+        // 最大5桁 (&#65536;)
+        for( lng = 0; lng <= 5; lng++ ){
+            if( in_char[ offset + lng ] < '0' || in_char[ offset + lng ] > '9' ) break;
         }
+        
+        // 桁数チェック
+        if( lng == 0 || lng == 6 ) return -1;
     }
 
     // 16 進数
     else{
 
-        for( int i = 0; i < lng; ++i ){
+        // 最大4桁 (&#xFFFF;)
+        for( lng = 0; lng <= 4; lng++ ){
             if(
                 ! (
-                    ( in_char[ offset + i ] >= '0' && in_char[ offset + i ] <= '9' )
-                    || ( in_char[ offset + i ] >= 'a' && in_char[ offset + i ] <= 'f' )
-                    || ( in_char[ offset + i ] >= 'A' && in_char[ offset + i ] <= 'F' )
+                    ( in_char[ offset + lng ] >= '0' && in_char[ offset + lng ] <= '9' )
+                    || ( in_char[ offset + lng ] >= 'a' && in_char[ offset + lng ] <= 'f' )
+                    || ( in_char[ offset + lng ] >= 'A' && in_char[ offset + lng ] <= 'F' )
                     )
-                ) return -1;
+                ) break;
         }
+        
+        // 桁数チェック
+        if( lng == 0 || lng == 5 ) return -1;
     }
 
     return lng;
@@ -1490,13 +1491,13 @@ const std::string MISC::utf8_fix_wavedash( const std::string& str, const int mod
 {
     // WAVE DASH 問題
     const size_t size = 4;
-    const char Win[size][4] = {
+    const unsigned char Win[size][4] = {
         { 0xef, 0xbd, 0x9e, '\0' }, // FULLWIDTH TILDE (U+FF5E)
         { 0xe2, 0x80, 0x95, '\0' }, // HORIZONTAL BAR (U+2015)
         { 0xe2, 0x88, 0xa5, '\0' }, // PARALLEL TO (U+2225)
         { 0xef, 0xbc, 0x8d, '\0' }  // FULLWIDTH HYPHEN-MINUS (U+FF0D)
     };
-    const char Unix[size][4] = {
+    const unsigned char Unix[size][4] = {
         { 0xe3, 0x80, 0x9c, '\0' }, // WAVE DASH (U+301C)
         { 0xe2, 0x80, 0x94, '\0' }, // EM DASH(U+2014)
         { 0xe2, 0x80, 0x96, '\0' }, // DOUBLE VERTICAL LINE (U+2016)
