@@ -6,6 +6,7 @@
 #define _MISCUTIL_H
 
 #include <string>
+#include <cstring>
 #include <list>
 #include <vector>
 #include <glibmm.h>
@@ -34,6 +35,14 @@ namespace MISC
          UCS2MODE_OTHER
      };
 
+
+     // utf8_fix_wavedash のモード
+     enum
+     {
+         UNIXtoWIN = 0,
+         WINtoUNIX
+     };
+
     // str を "\n" ごとに区切ってlistにして出力
     const std::list< std::string > get_lines( const std::string& str );
 
@@ -111,7 +120,7 @@ namespace MISC
     // dig: 桁数、0なら失敗
     // n : str から何バイト読み取ったか
     // 戻り値: 数値
-    const int str_to_uint( const char* str, unsigned int& dig, unsigned int& n );
+    const int str_to_uint( const char* str, size_t& dig, size_t& n );
 
     // 数字　-> 文字変換
     const std::string itostr( const int n );
@@ -127,6 +136,17 @@ namespace MISC
     // strが半角でmaxsize文字を超えたらカットして後ろに...を付ける
     const std::string cut_str( const std::string& str, const unsigned int maxsize );
 
+    // 正規表現のメタ文字が含まれているか
+    // escape == true ならエスケープを考慮 (例)  escape == true なら \+ → \+ のまま、falseなら \+ → \\\+
+    const bool has_regex_metachar( const std::string& str, const bool escape );
+
+    // 正規表現のメタ文字をエスケープ
+    // escape == true ならエスケープを考慮 (例)  escape == true なら \+ → \+ のまま、falseなら \+ → \\\+
+    const std::string regex_escape( const std::string& str, const bool escape );
+
+    // 正規表現のメタ文字をアンエスケープ
+    const std::string regex_unescape( const std::string& str );
+
     // HTMLエスケープ
     // include_url : URL中でもエスケープする( デフォルト = true )
     const std::string html_escape( const std::string& str, const bool include_url = true );
@@ -169,6 +189,32 @@ namespace MISC
     // 遅いので連続的な処理が必要な時は使わないこと
     const std::string Iconv( const std::string& str, const std::string& coding_from, const std::string& coding_to );
 
+    // 「&#数字;」形式の数字参照文字列の中の「数字」部分の文字列長
+    //
+    // in_char: 入力文字列、in_char[0] == "&" && in_char[1] == "#" であること
+    // offset : 開始位置が返る
+    //
+    // 戻り値 : 「&#数字;」の中の数字の文字列の長さ、変換出来ないときは -1
+    //
+    // 例 : &#9999; なら 戻り値 = 4、 offset = 2
+    //
+    const int spchar_number_ln( const char* in_char, int& offset );
+
+    // 「&#数字;」形式の数字参照文字列を数字(int)に変換する
+    //
+    // 最初に MISC::spchar_number_ln() を呼び出して offset と lng を取得すること
+    //
+    // in_char: 入力文字列、in_char[0] == "&" && in_char[1] == "#" であること
+    // offset : spchar_number_ln() の戻り値
+    // lng : spchar_number_ln() の戻り値
+    //
+    // 戻り値 : 「&#数字;」の中の数字(int型)
+    //
+    const int decode_spchar_number( const char* in_char, const int offset, const int lng );
+
+    // str に含まれる「&#数字;」形式の数字参照文字列を全てユニーコード文字に変換する
+    const std::string decode_spchar_number( const std::string& str );
+
     // utf-8 -> ucs2 変換
     // 入力 : utfstr 入力文字 (UTF-8)
     // 出力 :  byte  長さ(バイト) utfstr が ascii なら 1, UTF-8 なら 2 or 3 or 4 を入れて返す
@@ -183,6 +229,9 @@ namespace MISC
     // 戻り値 : バイト数
     const int ucs2toutf8( const int ucs2, char* utfstr );
 
+    // WAVEDASHなどのWindows系UTF-8文字をUnix系文字と相互変換
+    const std::string utf8_fix_wavedash( const std::string& str, const int mode );
+
     // str を大文字化
     const std::string toupper_str( const std::string& str );
 
@@ -204,7 +253,20 @@ namespace MISC
 
     // 文字数を限定して環境変数の値を返す
     const std::string getenv_limited( const char *name, const size_t size = 1 );
+
+    // pathセパレータを / に置き換える
+    const std::string recover_path( const std::string& str );
+    const std::list< std::string > recover_path( const std::list< std::string >& list_str );
+
+    // 文字列(utf-8)に全角英数字が含まれるか判定する
+    const bool has_widechar( const char* str );
+
+    // 全角英数字(str1) -> 半角英数字(str2)
+    // table_pos : 置き換えた文字列の位置
+    // n : str2 と table_pos のバッファサイズ
+    void asc( const char* str1, char* str2, int* table_pos, const size_t n );
 }
 
 
 #endif
+
