@@ -121,6 +121,12 @@ namespace MESSAGE
         // 色初期化
         void init_color();
 
+        // 名前欄に名前をセット
+        void set_name();
+
+        // メール欄にアドレスをセット
+        void set_mail();
+
         // 自分の書き込みの判定用データの保存
         void push_logitem();
 
